@@ -163,12 +163,7 @@ class Spider(SpiderHook):
         self.cancel_tasks = cancel_tasks
         self.is_async_start = is_async_start
 
-        # set logger
-        if self.custom_settings and self.custom_settings.get('LOG_FILE'):
-            LOG_FILE, LOG_LEVEL = self.custom_settings.get('LOG_FILE'),self.custom_settings.get('LOG_LEVEL','INFO')
-            self.logger = get_logger(name=self.name,filename=LOG_FILE,level=LOG_LEVEL)
-        else:
-            self.logger = check_logger(name=self.name)
+
 
         # customize middleware
         if isinstance(middleware, list):
@@ -187,6 +182,18 @@ class Spider(SpiderHook):
             self.concurrency = settings.CONCURRENT_REQUESTS
 
 
+        # set logger
+        if  isinstance(self.settings_attr,dict) and self.settings_attr.get('LOG_FILE'):
+            LOG_FILE, LOG_LEVEL = self.settings_attr.get('LOG_FILE'),self.settings_attr.get('LOG_LEVEL','INFO')
+            self.logger = get_logger(name=self.name,filename=LOG_FILE,level=LOG_LEVEL)
+
+        elif self.custom_settings and self.custom_settings.get('LOG_FILE'):
+            LOG_FILE, LOG_LEVEL = self.custom_settings.get('LOG_FILE'),self.custom_settings.get('LOG_LEVEL','INFO')
+            self.logger = get_logger(name=self.name,filename=LOG_FILE,level=LOG_LEVEL)
+        else:
+            self.logger = check_logger(name=self.name)
+
+
         # semaphore, used for concurrency control
         self.sem = asyncio.Semaphore(self.concurrency)
 
